# clir
Clir provides a clear and fast way to store and recover your commands.

## Installation
Install `clir` using pip.

```bash
pip3 install clir
```

## Usage
First of all, initialize clir. This will create the necessary cofig files.
```bash
clir init
```

See all the obption available with
```bash
clir --help
```